@@ -106,9 +106,9 @@ Obtain the final unicode string by calling ``unicode()`` on the ``HTML``
 instance:
 
 >>> h = HTML()
->>> h.p(u'Some Euro: €1.14')
+>>> h.p(u'Some Euro: \u20ac1.14')
 >>> unicode(h)
-u'<p>Some Euro: €1.14</p>'
+u'<p>Some Euro: \u20ac1.14</p>'
 
 If (under Python 2.x) you add non-unicode strings or attempt to get the
 resultant HTML source through any means other than ``unicode()`` then you
@@ -155,6 +155,14 @@ with the appropriate XHTML minimized tag syntax. For example:
 <p></p>
 <br />
 
+Installation
+------------
+
+Under Python 2 you should just ``python setup.py install`` but under Python
+3 you will need to ``python3 setup.py build install`` -- note the
+additional **build** command.
+
+
 Version History (in Brief)
 --------------------------
 
@@ -176,7 +184,7 @@ See the end of the source file for the license of use.
 XHTML support was contributed by Michael Haubenwallner.
 '''
 from __future__ import with_statement
-__version__ = '1.8'
+__version__ = '1.9'
 
 import unittest
 import cgi
